

Example Project
===============
This is a sample repo to test how the CoastSat package could be built.

Installing
============

.. code-block:: bash

    pip install coastsat_pkg_test1

Usage
=====

.. code-block:: bash

    >>> from src.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()
    '0.24.2'
